@@ -15,5 +15,8 @@ NSView *my_getContentView(void *xid) {
 
 double my_getScalingFactor(void *xid) {
     NSWindow *win = (NSWindow *)xid;
-    return [win backingScaleFactor];
+    NSView *view = [win contentView];
+    NSSize s = [view convertSizeToBacking:NSMakeSize(10, 10)];
+    int scale = ((int)(s.width + 0.5) > 10 ? 2 : 1);
+    return (double)scale;
 }
\ No newline at end of file
